@@ -128,7 +128,7 @@ class TestConfiguration:
         Configuration._create(user_agent='test', hdx_config_dict={'hdx_site': 'prod', 'hdx_read_only': True, 'hdx_key': 'abcde'},
                               hdx_base_config_dict={
                                                  'hdx_prod_site': {
-                                                     'url': 'https://data.humdata.org/',
+                                                     'url': 'https://data.humdata.org',
                                                  },
                                                  'XYZ': {'567': 987}
                                              },
@@ -137,11 +137,13 @@ class TestConfiguration:
             'hdx_site': 'prod',
             'hdx_read_only': True,
             'hdx_key': 'abcde',
-            'tags_cleanup_url': 'https://raw.githubusercontent.com/OCHA-DAP/hdx-python-api/master/tests/fixtures/HDX_Tags_Cleaning.csv',
             'hdx_prod_site': {
-                'url': 'https://data.humdata.org/',
+                'url': 'https://data.humdata.org',
             },
-            'XYZ': {'567': 987}
+            'XYZ': {'567': 987},
+            'approved_tags_vocabulary': 'Topics',
+            'tags_list_url': 'https://raw.githubusercontent.com/OCHA-DAP/hdx-python-api/master/tests/fixtures/Accepted_Tags.csv',
+            'tags_mapping_url': 'https://raw.githubusercontent.com/OCHA-DAP/hdx-python-api/master/tests/fixtures/Tag_Mapping.csv',
         }
 
         configuration = Configuration.read()
@@ -153,7 +155,7 @@ class TestConfiguration:
             hdx_config_dict={'hdx_site': 'prod', 'hdx_read_only': True, 'hdx_key': 'abcde', 'user_agent': 'test'},
             hdx_base_config_dict={
                 'hdx_prod_site': {
-                    'url': 'https://data.humdata.org/',
+                    'url': 'https://data.humdata.org',
                 },
                 'XYZ': {'567': 987}
             },
@@ -215,12 +217,11 @@ hello there'''
             'hdx_site': 'test',
             'hdx_read_only': False,
             'hdx_key': '54321',
-            'tags_cleanup_url': 'https://raw.githubusercontent.com/OCHA-DAP/hdx-python-api/master/tests/fixtures/HDX_Tags_Cleaning.csv',
             'hdx_prod_site': {
-                'url': 'https://data.humdata.org/',
+                'url': 'https://data.humdata.org',
             },
             'hdx_test_site': {
-                'url': 'https://test-data.humdata.org/',
+                'url': 'https://test-data.humdata.org',
                 'username': 'tumteetum',
                 'password': 'tumteetumteetum'
             },
@@ -230,6 +231,9 @@ hello there'''
             ]},
             'resource': {'required_fields': ['name', 'description']},
             'showcase': {'required_fields': ['name']},
+            'approved_tags_vocabulary': 'Topics',
+            'tags_list_url': 'https://raw.githubusercontent.com/OCHA-DAP/hdx-python-api/master/tests/fixtures/Accepted_Tags.csv',
+            'tags_mapping_url': 'https://raw.githubusercontent.com/OCHA-DAP/hdx-python-api/master/tests/fixtures/Tag_Mapping.csv',
         }
         assert Configuration.read() == expected_configuration
 
@@ -240,12 +244,11 @@ hello there'''
             'hdx_site': 'prod',
             'hdx_read_only': False,
             'hdx_key': '12345',
-            'tags_cleanup_url': 'https://raw.githubusercontent.com/OCHA-DAP/hdx-python-api/master/tests/fixtures/HDX_Tags_Cleaning.csv',
             'hdx_prod_site': {
-                'url': 'https://data.humdata.org/',
+                'url': 'https://data.humdata.org',
             },
             'hdx_test_site': {
-                'url': 'https://test-data.humdata.org/',
+                'url': 'https://test-data.humdata.org',
                 'username': 'lala',
                 'password': 'lalala'
             },
@@ -256,6 +259,9 @@ hello there'''
             ]},
             'resource': {'required_fields': ['package_id', 'name', 'description']},
             'showcase': {'required_fields': ['name', 'title']},
+            'approved_tags_vocabulary': 'Topics',
+            'tags_list_url': 'https://raw.githubusercontent.com/OCHA-DAP/hdx-python-api/master/tests/fixtures/Accepted_Tags.csv',
+            'tags_mapping_url': 'https://raw.githubusercontent.com/OCHA-DAP/hdx-python-api/master/tests/fixtures/Tag_Mapping.csv',
         }
         assert Configuration.read() == expected_configuration
 
@@ -266,19 +272,19 @@ hello there'''
             'hdx_read_only': False,
             'hdx_key': '12345',
             'hdx_prod_site': {
-                'url': 'https://data.humdata.org/',
+                'url': 'https://data.humdata.org',
             },
             'hdx_demo_site': {
-                'url': 'https://demo-data.humdata.org/',
+                'url': 'https://demo-data.humdata.org',
             },
             'hdx_test_site': {
-                'url': 'https://test-data.humdata.org/',
+                'url': 'https://test-data.humdata.org',
             },
             'hdx_feature_site': {
-                'url': 'https://feature-data.humdata.org/',
+                'url': 'https://feature-data.humdata.org',
             },
             'hdx_dev_site': {
-                'url': 'http://data.dev.humdata.org/',
+                'url': 'http://data.dev.humdata.org',
             },
             'dataset': {'required_fields': [
                 'name',
@@ -342,7 +348,13 @@ hello there'''
                 'title',
                 'view_type',
             ]},
-            'tags_cleanup_url': 'https://docs.google.com/spreadsheets/d/e/2PACX-1vTyUP_oS878LihWM7iR0qry0OZP44BKyVXc1P_SoM0FEvbVGdOQxxlQvBWT_vwwGNaAbmuSeTg1FwuP/pub?gid=346948259&single=true&output=csv'
+            'vocabulary': {'required_fields': [
+                'name',
+                'tags',
+            ]},
+            'approved_tags_vocabulary': 'Topics',
+            'tags_list_url': 'https://docs.google.com/spreadsheets/d/e/2PACX-1vRjeajloIuQl8mfTSHU71ZgbHSgYYUgHrLqyjHSuQJ-zMqS3SVM9hJqMs72L-84LQ/pub?gid=1739051517&single=true&output=csv',
+            'tags_mapping_url': 'https://docs.google.com/spreadsheets/d/e/2PACX-1vRjeajloIuQl8mfTSHU71ZgbHSgYYUgHrLqyjHSuQJ-zMqS3SVM9hJqMs72L-84LQ/pub?gid=334970416&single=true&output=csv'
         }
         assert Configuration.read() == expected_configuration
         Configuration._create(user_agent='test', hdx_config_yaml=hdx_config_yaml, project_config_dict={'abc': '123'})
@@ -356,19 +368,19 @@ hello there'''
             'hdx_read_only': False,
             'hdx_key': '12345',
             'hdx_prod_site': {
-                'url': 'https://data.humdata.org/',
+                'url': 'https://data.humdata.org',
             },
             'hdx_demo_site': {
-                'url': 'https://demo-data.humdata.org/',
+                'url': 'https://demo-data.humdata.org',
             },
             'hdx_test_site': {
-                'url': 'https://test-data.humdata.org/',
+                'url': 'https://test-data.humdata.org',
             },
             'hdx_feature_site': {
-                'url': 'https://feature-data.humdata.org/',
+                'url': 'https://feature-data.humdata.org',
             },
             'hdx_dev_site': {
-                'url': 'http://data.dev.humdata.org/',
+                'url': 'http://data.dev.humdata.org',
             },
             'my_param': 'abc',
             'dataset': {'required_fields': [
@@ -433,7 +445,13 @@ hello there'''
                 'title',
                 'view_type',
             ]},
-            'tags_cleanup_url': 'https://docs.google.com/spreadsheets/d/e/2PACX-1vTyUP_oS878LihWM7iR0qry0OZP44BKyVXc1P_SoM0FEvbVGdOQxxlQvBWT_vwwGNaAbmuSeTg1FwuP/pub?gid=346948259&single=true&output=csv'
+            'vocabulary': {'required_fields': [
+                'name',
+                'tags',
+            ]},
+            'approved_tags_vocabulary': 'Topics',
+            'tags_list_url': 'https://docs.google.com/spreadsheets/d/e/2PACX-1vRjeajloIuQl8mfTSHU71ZgbHSgYYUgHrLqyjHSuQJ-zMqS3SVM9hJqMs72L-84LQ/pub?gid=1739051517&single=true&output=csv',
+            'tags_mapping_url': 'https://docs.google.com/spreadsheets/d/e/2PACX-1vRjeajloIuQl8mfTSHU71ZgbHSgYYUgHrLqyjHSuQJ-zMqS3SVM9hJqMs72L-84LQ/pub?gid=334970416&single=true&output=csv'
         }
         assert Configuration.read() == expected_configuration
 
@@ -443,21 +461,20 @@ hello there'''
             'hdx_site': 'prod',
             'hdx_read_only': False,
             'hdx_key': '12345',
-            'tags_cleanup_url': 'https://raw.githubusercontent.com/OCHA-DAP/hdx-python-api/master/tests/fixtures/HDX_Tags_Cleaning.csv',
             'hdx_prod_site': {
-                'url': 'https://data.humdata.org/',
+                'url': 'https://data.humdata.org',
             },
             'hdx_demo_site': {
-                'url': 'https://demo-data.humdata.org/',
+                'url': 'https://demo-data.humdata.org',
             },
             'hdx_test_site': {
-                'url': 'https://test-data.humdata.org/',
+                'url': 'https://test-data.humdata.org',
             },
             'hdx_feature_site': {
-                'url': 'https://feature-data.humdata.org/',
+                'url': 'https://feature-data.humdata.org',
             },
             'hdx_dev_site': {
-                'url': 'http://data.dev.humdata.org/',
+                'url': 'http://data.dev.humdata.org',
             },
             'dataset': {'required_fields': [
                 'name',
@@ -521,6 +538,13 @@ hello there'''
                 'title',
                 'view_type',
             ]},
+            'vocabulary': {'required_fields': [
+                'name',
+                'tags',
+            ]},
+            'approved_tags_vocabulary': 'Topics',
+            'tags_list_url': 'https://raw.githubusercontent.com/OCHA-DAP/hdx-python-api/master/tests/fixtures/Accepted_Tags.csv',
+            'tags_mapping_url': 'https://raw.githubusercontent.com/OCHA-DAP/hdx-python-api/master/tests/fixtures/Tag_Mapping.csv',
         }
         assert Configuration.read() == expected_configuration
 
@@ -529,8 +553,9 @@ hello there'''
                               hdx_base_config_dict={}, project_config_yaml=project_config_yaml)
         actual_configuration = Configuration.read()
         assert actual_configuration.get_api_key() == '12345'
-        assert actual_configuration.get_hdx_site_url() == 'https://data.humdata.org/'
+        assert actual_configuration.get_hdx_site_url() == 'https://data.humdata.org'
         assert actual_configuration._get_credentials() is None
+        assert actual_configuration.get_dataset_url('mydataset') == 'https://data.humdata.org/dataset/mydataset'
 
     def test_set_hdx_key_value(self, project_config_yaml):
         Configuration._create(user_agent='test', hdx_site='prod', hdx_key='TEST_HDX_KEY',
